What is ASTK?
===============

**ASTK** is a command-line software for comprehensive alternative splicing analysis including:
- characterizing distribution and expression patterns of alternative splicing events
- systematically analyzing functional effects of AS events at the gene- and exon-level respectively
- dissecting out splicing-associated sequence features and epigenetic marks
- inferring the splicing regulatory code for each type of AS. 

<img src='https://huang-sh.github.io/astk-doc/static/img/workflow.png' alt="workflow.png"></img>

Documentation
===============
The documentation for ***ASTK*** is available on [astk-doc](https://huang-sh.github.io/astk-doc/).

How to cite
===============
Huang, S., He, J., Yu, L., Guo, J., Jiang, S., Sun, Z., Cheng, L., Chen, X., Ji, X. and Zhang, Y. (2024), ASTK: A Machine Learning-Based Integrative Software for Alternative Splicing Analysis. Adv. Intell. Syst. 2300594. https://doi.org/10.1002/aisy.202300594


How to contact
===============

- Shenghui Huang (hsh-me@outlook.com)