# $Id: aster_profile.sh 2252 2006-09-13 12:17:43Z courtois $
#
# aster_profile.sh : initialize the environment for astk services
# (sh, ksh, bash syntax)
#
# If variables are depending on Code_Aster version, use ENV_SH in
# the corresponding 'config.txt' file.
#
# $ASTER_VERSION is now obsolete.
#
ASTER_ROOT=?ASTER_ROOT?
export ASTER_ROOT

LD_LIBRARY_PATH=?HOME_PYTHON?/lib:$ASTER_ROOT/public/lib:$LD_LIBRARY_PATH
export LD_LIBRARY_PATH

# this should not be usefull...
#PYTHONHOME=?HOME_PYTHON?
#export PYTHONHOME

# optional settings
# DO NOT EDIT FOLLOWING LINE !
#?OPT_ENV?
